@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2005-2007 by Rajko Albrecht                             *
+ *   Copyright (C) 2005-2009 by Rajko Albrecht                             *
  *   ral@alwins-world.de                                                   *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -65,7 +65,7 @@ public:
     virtual bool closeUrl();
     static KAboutData* createAboutData();
 
-signals:
+Q_SIGNALS:
     void refreshTree();
     void settingsChanged();
 
@@ -91,9 +91,6 @@ protected slots:
     virtual void slotDisplayIgnored(bool);
     virtual void slotDisplayUnkown(bool);
     virtual void slotUrlChanged(const QString&);
-#if KDE_VERSION_MAJOR<4
-    void reportBug();
-#endif
     void showAboutApplication();
     void appHelpActivated();
     virtual void slotShowSettings();
