@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2005 by Rajko Albrecht                                  *
+ *   Copyright (C) 2005-2009 by Rajko Albrecht                             *
  *   ral@alwins-world.de                                                   *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -19,24 +19,30 @@
  ***************************************************************************/
 #include "revisiontree.h"
 #include "../stopdlg.h"
-#include "svnqt/log_entry.hpp"
+#include "src/svnqt/log_entry.h"
+#include "src/svnqt/cache/LogCache.h"
+#include "src/svnqt/cache/ReposLog.h"
+#include "src/svnqt/cache/ReposConfig.h"
+#include "src/svnqt/url.h"
+#include "src/svnqt/client_parameter.h"
 #include "helpers/sub2qt.h"
 #include "revtreewidget.h"
 #include "revgraphview.h"
 #include "elogentry.h"
+#include "src/svnfrontend/fronthelpers/cursorstack.h"
+#include "src/settings/kdesvnsettings.h"
 
 #include <kdebug.h>
-#include <kprogress.h>
+#include <kprogressdialog.h>
 #include <klocale.h>
-#include <kapp.h>
-#include <klistview.h>
-#include <kmdcodec.h>
+#include <kapplication.h>
+#include <kcodecs.h>
+#include <kmessagebox.h>
 
 #include <qwidget.h>
 #include <qdatetime.h>
 #include <qlabel.h>
 #include <qfile.h>
-#include <qtextstream.h>
 #include <qregexp.h>
 
 #define INTERNALCOPY 1
@@ -62,7 +68,7 @@ public:
     svn::Client*m_Client;
     QObject* m_Listener;
 
-    bool getLogs(const QString&,const svn::Revision&startr,const svn::Revision&endr);
+    bool getLogs(const QString&,const svn::Revision&startr,const svn::Revision&endr,const QString&origin);
 };
 
 RtreeData::RtreeData()
@@ -80,17 +86,34 @@ RtreeData::~RtreeData()
     delete progress;
 }
 
-bool RtreeData::getLogs(const QString&reposRoot,const svn::Revision&startr,const svn::Revision&endr)
+bool RtreeData::getLogs(const QString&reposRoot,const svn::Revision&startr,const svn::Revision&endr,const QString&origin)
 {
+    Q_UNUSED(origin);
     if (!m_Listener||!m_Client) {
         return false;
     }
+    svn::LogParameter params;
+    params.targets(reposRoot).revisionRange(endr,startr).peg(startr).limit(0).discoverChangedPathes(true).strictNodeHistory(false);
+    QStringList ex = svn::cache::ReposConfig::self()->readEntry(reposRoot,"tree_exclude_list",QStringList());
     try {
+        CursorStack a(Qt::BusyCursor);
         StopDlg sdlg(m_Listener,dlgParent,
-            0,"Logs","Getting logs - hit cancel for abort");
-        m_Client->log(reposRoot,endr,startr,m_OldHistory,true,false,0);
-    } catch (svn::ClientException ce) {
-        kdDebug()<<ce.msg() << endl;
+                     0,"Logs",i18n("Getting logs - hit cancel for abort"));
+        if (svn::Url::isLocal(reposRoot) ) {
+            m_Client->log(params.excludeList(ex),m_OldHistory);
+        } else {
+            svn::cache::ReposLog rl(m_Client,reposRoot);
+            if (rl.isValid()) {
+                rl.simpleLog(m_OldHistory,startr,endr,(!Kdesvnsettings::network_on()||!Kdesvnsettings::fill_cache_on_tree()),ex);
+            } else if (Kdesvnsettings::network_on()) {
+                m_Client->log(params.excludeList(ex),m_OldHistory);
+            } else {
+                KMessageBox::error(0,i18n("Could not retrieve logs, reason:\n%1",i18n("No logcache possible due broken database and networking not allowed.")));
+                return false;
+            }
+        }
+    } catch (const svn::Exception&ce) {
+        KMessageBox::error(0,i18n("Could not retrieve logs, reason:\n%1",ce.msg()));
         return false;
     }
     return true;
@@ -110,26 +133,24 @@ RevisionTree::RevisionTree(svn::Client*aClient,
     m_Data->m_Listener=aListener;
     m_Data->dlgParent=parent;
 
-    if (!m_Data->getLogs(reposRoot,startr,endr)) {
+    if (!m_Data->getLogs(reposRoot,startr,endr,origin)) {
         return;
     }
 
     long possible_rev=-1;
-    kdDebug()<<"Origin: "<<origin << endl;
 
-    m_Data->progress=new KProgressDialog(
-        parent,"progressdlg",i18n("Scanning logs"),i18n("Scanning the logs for %1").arg(origin),true);
+    m_Data->progress=new KProgressDialog(parent,i18n("Scanning logs"),i18n("Scanning the logs for %1",origin));
     m_Data->progress->setMinimumDuration(100);
     m_Data->progress->show();
     m_Data->progress->setAllowCancel(true);
-    m_Data->progress->progressBar()->setTotalSteps(m_Data->m_OldHistory.size());
+    m_Data->progress->progressBar()->setRange(0,m_Data->m_OldHistory.size());
     m_Data->progress->setAutoClose(false);
     m_Data->progress->show();
     bool cancel=false;
     svn::LogEntriesMap::Iterator it;
     unsigned count = 0;
     for (it=m_Data->m_OldHistory.begin();it!=m_Data->m_OldHistory.end();++it) {
-        m_Data->progress->progressBar()->setProgress(count);
+        m_Data->progress->progressBar()->setValue(count);
         kapp->processEvents();
         if (m_Data->progress->wasCancelled()) {
             cancel=true;
@@ -142,7 +163,7 @@ RevisionTree::RevisionTree(svn::Client*aClient,
             m_Data->min_rev=it.key();
         }
         if (baserevision.kind()==svn_opt_revision_date) {
-            if (baserevision.date()<=it.data().date && possible_rev==-1||possible_rev>it.key()) {
+            if ( (baserevision.date()<=it.value().date && possible_rev==-1) || possible_rev>it.key()) {
                 possible_rev=it.key();
             }
         }
@@ -156,17 +177,13 @@ RevisionTree::RevisionTree(svn::Client*aClient,
         m_Baserevision=possible_rev;
     }
     if (!cancel) {
-        kdDebug( )<<" max revision " << m_Data->max_rev
-            << " min revision " << m_Data->min_rev << endl;
         if (topDownScan()) {
-            kdDebug()<<"topdown end"<<endl;
             m_Data->progress->setAutoReset(true);
-            m_Data->progress->progressBar()->setTotalSteps(100);
-            m_Data->progress->progressBar()->setPercentageVisible(false);
+            m_Data->progress->progressBar()->setRange(0,100);
+            m_Data->progress->progressBar()->setTextVisible(false);
             m_Data->m_stopTick.restart();
             m_Data->m_TreeDisplay=new RevTreeWidget(m_Data->m_Listener,m_Data->m_Client,treeParent);
             if (bottomUpScan(m_InitialRevsion,0,m_Path,0)) {
-                kdDebug()<<"Bottom up end"<<endl;
                 m_Valid=true;
                 m_Data->m_TreeDisplay->setBasePath(reposRoot);
                 m_Data->m_TreeDisplay->dumpRevtree();
@@ -175,8 +192,6 @@ RevisionTree::RevisionTree(svn::Client*aClient,
                 m_Data->m_TreeDisplay = 0;
             }
         }
-    } else {
-        kdDebug()<<"Canceld"<<endl;
     }
     m_Data->progress->hide();
 }
@@ -188,8 +203,9 @@ RevisionTree::~RevisionTree()
 
 bool RevisionTree::isDeleted(long revision,const QString&path)
 {
-    for (unsigned i = 0;i<m_Data->m_History[revision].changedPaths.count();++i) {
-        if (isParent(m_Data->m_History[revision].changedPaths[i].path,path) && m_Data->m_History[revision].changedPaths[i].action=='D') {
+    for (long i = 0;i<m_Data->m_History[revision].changedPaths.count();++i) {
+        if (isParent(m_Data->m_History[revision].changedPaths[i].path,path) &&
+            m_Data->m_History[revision].changedPaths[i].action=='D') {
             return true;
         }
     }
@@ -198,25 +214,25 @@ bool RevisionTree::isDeleted(long revision,const QString&path)
 
 bool RevisionTree::topDownScan()
 {
-    m_Data->progress->progressBar()->setTotalSteps(m_Data->max_rev-m_Data->min_rev);
+    m_Data->progress->progressBar()->setRange(0,m_Data->max_rev-m_Data->min_rev);
     bool cancel=false;
     QString label;
     QString olabel = m_Data->progress->labelText();
     for (long j=m_Data->max_rev;j>=m_Data->min_rev;--j) {
-        m_Data->progress->progressBar()->setProgress(m_Data->max_rev-j);
+        m_Data->progress->progressBar()->setValue(m_Data->max_rev-j);
         kapp->processEvents();
         if (m_Data->progress->wasCancelled()) {
             cancel=true;
             break;
         }
-        for (unsigned i = 0; i<m_Data->m_OldHistory[j].changedPaths.count();++i) {
+        for (long i = 0; i<m_Data->m_OldHistory[j].changedPaths.count();++i) {
             if (i>0 && i%100==0) {
                 if (m_Data->progress->wasCancelled()) {
                     cancel=true;
                     break;
                 }
-                label = QString("%1<br>Check change entry %2 of %3").arg(olabel).arg(i).arg(m_Data->m_OldHistory[j].changedPaths.count());
-                m_Data->progress->setLabel(label);
+                label = i18n("%1<br>Check change entry %2 of %3",olabel,i,m_Data->m_OldHistory[j].changedPaths.count());
+                m_Data->progress->setLabelText(label);
                 kapp->processEvents();
             }
             /* find min revision of item */
@@ -230,34 +246,33 @@ bool RevisionTree::topDownScan()
                         m_Path=m_Data->m_OldHistory[j].changedPaths[i].copyFromPath;
                         m_Path+=r;
                     }
-                } else if (m_Data->m_OldHistory[j].changedPaths[i].path==m_Path){
+                } else if (m_Data->m_OldHistory[j].changedPaths[i].path==m_Path && m_Data->m_OldHistory[j].changedPaths[i].copyToPath.isEmpty()){
                     // here it is added
                     m_InitialRevsion = m_Data->m_OldHistory[j].revision;
                 }
             }
         }
     }
-    kdDebug()<<"Stage one done"<<endl;
     if (cancel==true) {
         return false;
     }
-    m_Data->progress->setLabel(olabel);
+    m_Data->progress->setLabelText(olabel);
     /* find forward references and filter them out */
     for (long j=m_Data->max_rev;j>=m_Data->min_rev;--j) {
-        m_Data->progress->progressBar()->setProgress(m_Data->max_rev-j);
+        m_Data->progress->progressBar()->setValue(m_Data->max_rev-j);
         kapp->processEvents();
         if (m_Data->progress->wasCancelled()) {
             cancel=true;
             break;
         }
-        for (unsigned i = 0; i<m_Data->m_OldHistory[j].changedPaths.count();++i) {
+        for (long i = 0; i<m_Data->m_OldHistory[j].changedPaths.count();++i) {
             if (i>0 && i%100==0) {
                 if (m_Data->progress->wasCancelled()) {
                     cancel=true;
                     break;
                 }
-                label = QString("%1<br>Check change entry %2 of %3").arg(olabel).arg(i).arg(m_Data->m_OldHistory[j].changedPaths.count());
-                m_Data->progress->setLabel(label);
+                label = i18n("%1<br>Check change entry %2 of %3",olabel,i,m_Data->m_OldHistory[j].changedPaths.count());
+                m_Data->progress->setLabelText(label);
                 kapp->processEvents();
             }
             if (!m_Data->m_OldHistory[j].changedPaths[i].copyFromPath.isEmpty()) {
@@ -265,14 +280,13 @@ bool RevisionTree::topDownScan()
                 QString sourcepath = m_Data->m_OldHistory[j].changedPaths[i].copyFromPath;
                 char a = m_Data->m_OldHistory[j].changedPaths[i].action;
                 if (m_Data->m_OldHistory[j].changedPaths[i].path.isEmpty()) {
-                    kdDebug()<<"Empty entry! rev " << j << " source " << sourcepath << endl;
                     continue;
                 }
                 if (a=='R') {
                     m_Data->m_OldHistory[j].changedPaths[i].action=0;
                 } else if (a=='A'){
                     a=INTERNALCOPY;
-                    for (unsigned z = 0;z<m_Data->m_OldHistory[j].changedPaths.count();++z) {
+                    for (long z = 0;z<m_Data->m_OldHistory[j].changedPaths.count();++z) {
                         if (m_Data->m_OldHistory[j].changedPaths[z].action=='D'
                             && isParent(m_Data->m_OldHistory[j].changedPaths[z].path,sourcepath) ) {
                             a=INTERNALRENAME;
@@ -282,25 +296,22 @@ bool RevisionTree::topDownScan()
                     }
                     m_Data->m_History[r].addCopyTo(sourcepath,m_Data->m_OldHistory[j].changedPaths[i].path,j,a,r);
                     m_Data->m_OldHistory[j].changedPaths[i].action=0;
-                } else {
-                    kdDebug()<<"Action with source path but wrong action \""<<a<<"\" found!"<<endl;
                 }
             }
         }
     }
-    kdDebug()<<"Stage two done"<<endl;
     if (cancel==true) {
         return false;
     }
-    m_Data->progress->setLabel(olabel);
+    m_Data->progress->setLabelText(olabel);
     for (long j=m_Data->max_rev;j>=m_Data->min_rev;--j) {
-        m_Data->progress->progressBar()->setProgress(m_Data->max_rev-j);
+        m_Data->progress->progressBar()->setValue(m_Data->max_rev-j);
         kapp->processEvents();
         if (m_Data->progress->wasCancelled()) {
             cancel=true;
             break;
         }
-        for (unsigned i = 0; i<m_Data->m_OldHistory[j].changedPaths.count();++i) {
+        for (long i = 0; i<m_Data->m_OldHistory[j].changedPaths.count();++i) {
             if (m_Data->m_OldHistory[j].changedPaths[i].action==0) {
                 continue;
             }
@@ -309,25 +320,24 @@ bool RevisionTree::topDownScan()
                     cancel=true;
                     break;
                 }
-                label = QString("%1<br>Check change entry %2 of %3").arg(olabel).arg(i).arg(m_Data->m_OldHistory[j].changedPaths.count());
-                m_Data->progress->setLabel(label);
+                label = i18n("%1<br>Check change entry %2 of %3",olabel,i,m_Data->m_OldHistory[j].changedPaths.count());
+                m_Data->progress->setLabelText(label);
                 kapp->processEvents();
             }
-            m_Data->m_History[j].addCopyTo(m_Data->m_OldHistory[j].changedPaths[i].path,QString::null,-1,m_Data->m_OldHistory[j].changedPaths[i].action);
+            m_Data->m_History[j].addCopyTo(m_Data->m_OldHistory[j].changedPaths[i].path,QString(),-1,m_Data->m_OldHistory[j].changedPaths[i].action);
         }
         m_Data->m_History[j].author=m_Data->m_OldHistory[j].author;
         m_Data->m_History[j].date=m_Data->m_OldHistory[j].date;
         m_Data->m_History[j].revision=m_Data->m_OldHistory[j].revision;
         m_Data->m_History[j].message=m_Data->m_OldHistory[j].message;
     }
-    kdDebug()<<"Stage three done"<<endl;
     return !cancel;
 }
 
 bool RevisionTree::isParent(const QString&_par,const QString&tar)
 {
     if (_par==tar) return true;
-    QString par = _par+(_par.endsWith("/")?"":"/");
+    QString par = _par.endsWith('/')?_par:_par+'/';
     return tar.startsWith(par);
 }
 
@@ -338,9 +348,9 @@ bool RevisionTree::isValid()const
 
 static QString uniqueNodeName(long rev,const QString&path)
 {
-    QString res = KCodecs::base64Encode(path.local8Bit(),false);
-    res.replace("\"","_quot_");
-    res.replace(" ","_space_");
+    QString res = KCodecs::base64Encode(path.toLocal8Bit(),false);
+    res.replace('\"',"_quot_");
+    res.replace(' ',"_space_");
     QString n; n.sprintf("%05ld",rev);
     res = "\""+n+QString("_%1\"").arg(res);
     return res;
@@ -356,13 +366,13 @@ bool RevisionTree::bottomUpScan(long startrev,unsigned recurse,const QString&_pa
     /* this is required if an item will modified AND copied at same revision.*/
     long trev = -1;
 #ifdef DEBUG_PARSE
-    kdDebug()<<"Searching for "<<path<< " at revision " << startrev
+    kDebug(9510)<<"Searching for "<<path<< " at revision " << startrev
         << " recursion " << recurse << endl;
 #endif
     bool cancel = false;
     for (long j=startrev;j<=m_Data->max_rev;++j) {
         if (m_Data->m_stopTick.elapsed()>500) {
-            m_Data->progress->progressBar()->advance(1);
+            m_Data->progress->progressBar()->setValue(m_Data->progress->progressBar()->value()+1);
             kapp->processEvents();
             m_Data->m_stopTick.restart();
         }
@@ -370,7 +380,7 @@ bool RevisionTree::bottomUpScan(long startrev,unsigned recurse,const QString&_pa
             cancel=true;
             break;
         }
-        for (unsigned i=0;i<REVENTRY.changedPaths.count();++i) {
+        for (long i=0;i<REVENTRY.changedPaths.count();++i) {
             if (!isParent(FORWARDENTRY.path,path)) {
                 continue;
             }
@@ -379,7 +389,7 @@ bool RevisionTree::bottomUpScan(long startrev,unsigned recurse,const QString&_pa
                 bool get_out = false;
                 if (FORWARDENTRY.path!=path) {
 #ifdef DEBUG_PARSE
-                    kdDebug()<<"Parent rename? "<< FORWARDENTRY.path << " -> " << FORWARDENTRY.copyToPath << " -> " << FORWARDENTRY.copyFromPath << endl;
+                    kDebug(9510)<<"Parent rename? "<< FORWARDENTRY.path << " -> " << FORWARDENTRY.copyToPath << " -> " << FORWARDENTRY.copyFromPath << endl;
 #endif
                 }
                 if (FORWARDENTRY.action==INTERNALCOPY ||
@@ -409,12 +419,12 @@ bool RevisionTree::bottomUpScan(long startrev,unsigned recurse,const QString&_pa
                         /* skip items between */
                         j=lastrev;
 #ifdef DEBUG_PARSE
-                        kdDebug()<<"Renamed to "<< recPath << " at revison " << FORWARDENTRY.copyToRevision << endl;
+                        kDebug(9510)<<"Renamed to "<< recPath << " at revision " << FORWARDENTRY.copyToRevision << endl;
 #endif
                         path=recPath;
                     } else {
 #ifdef DEBUG_PARSE
-                        kdDebug()<<"Copy to "<< recPath << endl;
+                        kDebug(9510)<<"Copy to "<< recPath << endl;
 #endif
                         if (!bottomUpScan(FORWARDENTRY.copyToRevision,recurse+1,recPath,FORWARDENTRY.copyToRevision)) {
                             return false;
@@ -424,7 +434,7 @@ bool RevisionTree::bottomUpScan(long startrev,unsigned recurse,const QString&_pa
                     switch (FORWARDENTRY.action) {
                     case 'A':
 #ifdef DEBUG_PARSE
-                        kdDebug()<<"Inserting adding base item"<<endl;
+                        kDebug(9510)<<"Inserting adding base item"<<endl;
 #endif
                         n1 = uniqueNodeName(j,FORWARDENTRY.path);
                         m_Data->m_TreeDisplay->m_RevGraphView->m_Tree[n1].Action=FORWARDENTRY.action;
@@ -432,8 +442,9 @@ bool RevisionTree::bottomUpScan(long startrev,unsigned recurse,const QString&_pa
                         lastrev=j;
                     break;
                     case 'M':
+                    case 'R':
 #ifdef DEBUG_PARSE
-                        kdDebug()<<"Item modified at revision "<< j << " recurse " << recurse << endl;
+                        kDebug(9510)<<"Item modified at revision "<< j << " recurse " << recurse << endl;
 #endif
                         n1 = uniqueNodeName(j,FORWARDENTRY.path);
                         n2 = uniqueNodeName(lastrev,FORWARDENTRY.path);
@@ -448,7 +459,7 @@ bool RevisionTree::bottomUpScan(long startrev,unsigned recurse,const QString&_pa
                     break;
                     case 'D':
 #ifdef DEBUG_PARSE
-                        kdDebug()<<"(Sloppy match) Item deleted at revision "<< j << " recurse " << recurse << endl;
+                        kDebug(9510)<<"(Sloppy match) Item deleted at revision "<< j << " recurse " << recurse << endl;
 #endif
                         n1 = uniqueNodeName(j,path);
                         n2 = uniqueNodeName(lastrev,path);
@@ -470,7 +481,7 @@ bool RevisionTree::bottomUpScan(long startrev,unsigned recurse,const QString&_pa
                     switch (FORWARDENTRY.action) {
                     case 'D':
 #ifdef DEBUG_PARSE
-                        kdDebug()<<"(Exact match) Item deleted at revision "<< j << " recurse " << recurse << endl;
+                        kDebug(9510)<<"(Exact match) Item deleted at revision "<< j << " recurse " << recurse << endl;
 #endif
                         n1 = uniqueNodeName(j,path);
                         n2 = uniqueNodeName(lastrev,path);
