@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2005-2007 by Rajko Albrecht                             *
+ *   Copyright (C) 2005-2009 by Rajko Albrecht                             *
  *   ral@alwins-world.de                                                   *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -20,11 +20,11 @@
 #ifndef SVNACTIONS_H
 #define SVNACTIONS_H
 
-#include "src/svnqt/client.hpp"
-#include "src/svnqt/revision.hpp"
-#include "src/svnqt/smart_pointer.hpp"
-#include "src/svnqt/shared_pointer.hpp"
-#include "src/svnqt/svnqttypes.hpp"
+#include "src/svnqt/client.h"
+#include "src/svnqt/revision.h"
+#include "src/svnqt/smart_pointer.h"
+#include "src/svnqt/shared_pointer.h"
+#include "src/svnqt/svnqttypes.h"
 
 #include "simple_logcb.h"
 #include "frontendtypes.h"
@@ -86,7 +86,7 @@ public:
     bool addItems(const QStringList&w,svn::Depth depth=svn::DepthEmpty);
     void checkAddItems(const QString&path,bool print_error_box=true);
 
-    bool makeDelete(const svn::Pathes&);
+    bool makeDelete(const svn::Pathes&,bool keep_local=true,bool force=false);
     bool makeDelete(const QStringList&);
     void makeLock(const QStringList&,const QString&,bool);
     void makeUnlock(const QStringList&,bool);
@@ -129,7 +129,7 @@ public:
 
     void makeBlame(const svn::Revision&start, const svn::Revision&end, SvnItem*k);
     void makeBlame(const svn::Revision&start, const svn::Revision&end, const QString&,QWidget*parent=0,const svn::Revision&peg=svn::Revision::UNDEFINED,SimpleLogCb*_acb=0);
-    void makeUpdate(const QStringList&what,const svn::Revision&rev,bool recurse);
+    void makeUpdate(const QStringList&what,const svn::Revision&rev,svn::Depth depth);
     bool makeSwitch(const QString&rUrl,const QString&tPath,const svn::Revision&r,svn::Depth depth,const svn::Revision&peg,bool stickydepth,bool ignore_externals,bool allow_unversioned);
     bool makeSwitch(const QString&path,const QString&what);
     bool makeRelocate(const QString&fUrl,const QString&tUrl,const QString&path,bool rec = true);
@@ -141,6 +141,8 @@ public:
 
     QString getInfo(const SvnItemList& lst,const svn::Revision&rev,const svn::Revision&peg,bool recursive,bool all=true);
     QString getInfo(const QString&_what,const svn::Revision&rev,const svn::Revision&peg,bool recursive,bool all=true);
+    QString getInfo(const svn::InfoEntries&entries,const QString&what,bool all);
+
 
     QString makeMkdir(const QString&);
     bool makeMkdir(const QStringList&,const QString&);
@@ -182,6 +184,7 @@ public:
 
     bool doNetworking();
     virtual void doCommit(const SvnItemList&);
+    virtual void editProperties(SvnItem*k,const svn::Revision&rev);
 
 protected:
     svn::smart_pointer<SvnActionsData> m_Data;
@@ -194,9 +197,8 @@ protected:
     void makeDiffinternal(const QString&,const svn::Revision&,const QString&,const svn::Revision&,QWidget*,const svn::Revision&peg=svn::Revision::UNDEFINED);
     void makeDiffExternal(const QString&p1,const svn::Revision&start,const QString&p2,const svn::Revision&end,const svn::Revision&_peg,bool isDir,QWidget*p,bool rec=true);
 
-public slots:
+public Q_SLOTS:
     virtual void dispDiff(const QByteArray&);
-    virtual void slotProperties();
     virtual void slotNotifyMessage(const QString&);
     virtual void slotUpdateHeadRec();
     virtual void slotUpdateTo();
@@ -220,7 +222,7 @@ public slots:
     virtual void slotMergeWcRevisions(const QString&,const svn::Revision&,const svn::Revision&,bool,bool,bool,bool);
     virtual void slotMerge(const QString&,const QString&, const QString&,
                             const svn::Revision&,const svn::Revision&,const svn::Revision&,
-                            bool,bool,bool,bool);
+                            bool,bool,bool,bool,bool,bool);
     virtual void slotMergeExternal(const QString&src1,const QString&src2, const QString&target,
                                     const svn::Revision&rev1,const svn::Revision&rev2,const svn::Revision&_peg,bool);
     virtual void slotExtraLogMsg(const QString&);
@@ -229,7 +231,7 @@ public slots:
     virtual void slotCancel(bool);
     virtual void stopFillCache();
 
-signals:
+Q_SIGNALS:
     void clientException(const QString&);
     void sendNotify(const QString&);
     void reinitItem(SvnItem*);
@@ -242,8 +244,9 @@ signals:
     void sigCacheStatus(qlonglong,qlonglong);
     void sigCacheDataChanged();
     void sigItemsReverted(const QStringList&);
+    void sigExtraStatusMessage(const QString&);
 
-protected slots:
+protected Q_SLOTS:
     virtual void checkModthread();
     virtual void checkUpdateThread();
     virtual void slotProcessDataRead(const QByteArray&,WatchedProcess*);
