@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2005-2007 by Rajko Albrecht                             *
+ *   Copyright (C) 2005-2009 by Rajko Albrecht                             *
  *   ral@alwins-world.de                                                   *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -18,22 +18,22 @@
  *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
  ***************************************************************************/
 
-#ifndef __SVN_ITEM_H
-#define __SVN_ITEM_H
+#ifndef SVN_ITEM_H
+#define SVN_ITEM_H
 
-#include "src/svnqt/smart_pointer.hpp"
-#include "src/svnqt/status.hpp"
+#include "src/svnqt/smart_pointer.h"
+#include "src/svnqt/svnqttypes.h"
 #include <kmimetype.h>
-#include <qstring.h>
+#include <QString>
 #include <qdatetime.h>
-#include <qpixmap.h>
-#include <qptrlist.h>
+#include <QPixmap>
+#include <QList>
 
-class FileListViewItem;
+class SvnItemModelNode;
 class SvnItem_p;
 class SvnActions;
 class KFileItem;
-class KURL;
+class KUrl;
 
 namespace svn
 {
@@ -44,42 +44,50 @@ class SvnItem
 {
 public:
     SvnItem();
-    SvnItem(const svn::Status&);
+    SvnItem(const svn::StatusPtr&);
     virtual ~SvnItem();
 
     virtual const QString&fullName()const;
     virtual const QString&shortName()const;
     virtual const QString&Url()const;
-    virtual const KURL&kdeName(const svn::Revision&);
+    virtual const KUrl&kdeName(const svn::Revision&);
     virtual KMimeType::Ptr mimeType();
     virtual const QDateTime&fullDate()const;
     virtual bool isDir()const;
     virtual bool isVersioned()const;
+    virtual bool isConflicted()const;
     virtual bool isValid()const;
     virtual bool isRealVersioned()const;
     virtual bool isIgnored()const;
     virtual bool isRemoteAdded()const;
+    virtual bool isChanged()const;
+    virtual bool isLocalAdded()const;
     virtual QString infoText()const;
     virtual QString cmtAuthor()const;
     virtual long int cmtRev()const;
     virtual bool isLocked()const;
     virtual QString lockOwner()const;
     virtual QString getParentDir()const=0;
+    virtual SvnItem* getParentItem()const=0;
     virtual const svn::Revision&correctPeg()const=0;
-    virtual void refreshStatus(bool childs=false,QPtrList<SvnItem> *exclude = 0,bool depsonly=false)=0;
+    virtual svn::Revision revision()const;
+    virtual void refreshStatus(bool children=false,const QList<SvnItem*>&exclude=QList<SvnItem*>(),bool depsonly=false)=0;
 
     QPixmap getPixmap(int size,bool overlay=true);
     QPixmap getPixmap(const QPixmap&,int size,bool overlay=true);
 
-    virtual FileListViewItem*fItem(){return 0;}
-    virtual void setStat(const svn::Status&);
-    virtual const svn::Status& stat()const;
+    virtual SvnItemModelNode*sItem(){return 0;}
+    virtual void setStat(const svn::StatusPtr&);
+    virtual const svn::StatusPtr& stat()const;
     virtual bool isModified()const;
+    virtual bool isChildModified()const;
     bool isNormal()const;
     bool isMissing()const;
     bool isDeleted()const;
     const QString& getToolTipText();
-    KFileItem*fileItem();
+    virtual void generateToolTip(const svn::InfoEntry&entry);
+    bool hasToolTipText();
+    KFileItem fileItem();
 
 protected:
     bool m_overlaycolor;
@@ -103,7 +111,4 @@ protected:
 
 };
 
-typedef QPtrList<SvnItem> SvnItemList;
-typedef QPtrListIterator<SvnItem> SvnItemListIterator;
-
 #endif
